#!perl -T
use Test::More;
use Test::Exception;
use ok( 'Locale::CLDR' );
my $locale;

diag( "Testing Locale::CLDR v0.40.0, Perl $], $^X" );
use ok 'Locale::CLDR::Locales::Fr';
use ok 'Locale::CLDR::Locales::Fr::Any::Be';
use ok 'Locale::CLDR::Locales::Fr::Any::Bf';
use ok 'Locale::CLDR::Locales::Fr::Any::Bi';
use ok 'Locale::CLDR::Locales::Fr::Any::Bj';
use ok 'Locale::CLDR::Locales::Fr::Any::Bl';
use ok 'Locale::CLDR::Locales::Fr::Any::Ca';
use ok 'Locale::CLDR::Locales::Fr::Any::Cd';
use ok 'Locale::CLDR::Locales::Fr::Any::Cf';
use ok 'Locale::CLDR::Locales::Fr::Any::Cg';
use ok 'Locale::CLDR::Locales::Fr::Any::Ch';
use ok 'Locale::CLDR::Locales::Fr::Any::Ci';
use ok 'Locale::CLDR::Locales::Fr::Any::Cm';
use ok 'Locale::CLDR::Locales::Fr::Any::Dj';
use ok 'Locale::CLDR::Locales::Fr::Any::Dz';
use ok 'Locale::CLDR::Locales::Fr::Any::Fr';
use ok 'Locale::CLDR::Locales::Fr::Any::Ga';
use ok 'Locale::CLDR::Locales::Fr::Any::Gf';
use ok 'Locale::CLDR::Locales::Fr::Any::Gn';
use ok 'Locale::CLDR::Locales::Fr::Any::Gp';
use ok 'Locale::CLDR::Locales::Fr::Any::Gq';
use ok 'Locale::CLDR::Locales::Fr::Any::Ht';
use ok 'Locale::CLDR::Locales::Fr::Any::Km';
use ok 'Locale::CLDR::Locales::Fr::Any::Lu';
use ok 'Locale::CLDR::Locales::Fr::Any::Ma';
use ok 'Locale::CLDR::Locales::Fr::Any::Mc';
use ok 'Locale::CLDR::Locales::Fr::Any::Mf';
use ok 'Locale::CLDR::Locales::Fr::Any::Mg';
use ok 'Locale::CLDR::Locales::Fr::Any::Ml';
use ok 'Locale::CLDR::Locales::Fr::Any::Mq';
use ok 'Locale::CLDR::Locales::Fr::Any::Mr';
use ok 'Locale::CLDR::Locales::Fr::Any::Mu';
use ok 'Locale::CLDR::Locales::Fr::Any::Nc';
use ok 'Locale::CLDR::Locales::Fr::Any::Ne';
use ok 'Locale::CLDR::Locales::Fr::Any::Pf';
use ok 'Locale::CLDR::Locales::Fr::Any::Pm';
use ok 'Locale::CLDR::Locales::Fr::Any::Re';
use ok 'Locale::CLDR::Locales::Fr::Any::Rw';
use ok 'Locale::CLDR::Locales::Fr::Any::Sc';
use ok 'Locale::CLDR::Locales::Fr::Any::Sn';
use ok 'Locale::CLDR::Locales::Fr::Any::Sy';
use ok 'Locale::CLDR::Locales::Fr::Any::Td';
use ok 'Locale::CLDR::Locales::Fr::Any::Tg';
use ok 'Locale::CLDR::Locales::Fr::Any::Tn';
use ok 'Locale::CLDR::Locales::Fr::Any::Vu';
use ok 'Locale::CLDR::Locales::Fr::Any::Wf';
use ok 'Locale::CLDR::Locales::Fr::Any::Yt';
use ok 'Locale::CLDR::Locales::Fr::Any';

done_testing();
